aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/gpu
diff options
context:
space:
mode:
authorGravatar robertphillips@google.com <robertphillips@google.com@2bbb7eff-a529-9590-31e7-b0007b416f81>2013-08-20 17:49:04 +0000
committerGravatar robertphillips@google.com <robertphillips@google.com@2bbb7eff-a529-9590-31e7-b0007b416f81>2013-08-20 17:49:04 +0000
commit3055b700189afdd02486ed8f2279cea1d8897243 (patch)
treea66e6ce6e9717464dd67eb206f76440da9bab059 /include/gpu
parent4eaa6647e70c9404d1c920f674d706ca2d2a76b9 (diff)
Split SkDevice out of SkBitmapDevice
Diffstat (limited to 'include/gpu')
-rw-r--r--include/gpu/SkGpuDevice.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/include/gpu/SkGpuDevice.h b/include/gpu/SkGpuDevice.h
index 40d2554b00..a24128bd85 100644
--- a/include/gpu/SkGpuDevice.h
+++ b/include/gpu/SkGpuDevice.h
@@ -22,10 +22,10 @@ struct GrSkDrawProcs;
class GrTextContext;
/**
* Subclass of SkDevice, which directs all drawing to the GrGpu owned by the
* canvas.
*/
-class SK_API SkGpuDevice : public SkDevice {
+class SK_API SkGpuDevice : public SkBitmapDevice {
public:
/**
@@ -62,7 +62,7 @@ public:
virtual GrRenderTarget* accessRenderTarget() SK_OVERRIDE;
// overrides from SkDevice
virtual void clear(SkColor color) SK_OVERRIDE;
virtual void writePixels(const SkBitmap& bitmap, int x, int y,
@@ -101,11 +101,11 @@ public:
const SkColor colors[], SkXfermode* xmode,
const uint16_t indices[], int indexCount,
const SkPaint&) SK_OVERRIDE;
- virtual void drawDevice(const SkDraw&, SkDevice*, int x, int y,
+ virtual void drawDevice(const SkDraw&, SkBaseDevice*, int x, int y,
const SkPaint&) SK_OVERRIDE;
virtual bool filterTextFlags(const SkPaint&, TextFlags*) SK_OVERRIDE;
- virtual void flush();
+ virtual void flush() SK_OVERRIDE;
virtual void onAttachToCanvas(SkCanvas* canvas) SK_OVERRIDE;
virtual void onDetachFromCanvas() SK_OVERRIDE;
@@ -123,7 +123,7 @@ public:
class SkAutoCachedTexture; // used internally
protected:
// overrides from SkDevice
virtual bool onReadPixels(const SkBitmap& bitmap,
int x, int y,
SkCanvas::Config8888 config8888) SK_OVERRIDE;
@@ -145,11 +145,11 @@ private:
// used by createCompatibleDevice
SkGpuDevice(GrContext*, GrTexture* texture, bool needClear);
- // override from SkDevice
- virtual SkDevice* onCreateCompatibleDevice(SkBitmap::Config config,
- int width, int height,
- bool isOpaque,
- Usage usage) SK_OVERRIDE;
+ // override from SkBaseDevice
+ virtual SkBaseDevice* onCreateCompatibleDevice(SkBitmap::Config config,
+ int width, int height,
+ bool isOpaque,
+ Usage usage) SK_OVERRIDE;
SkDrawProcs* initDrawForText(GrTextContext*);
@@ -192,7 +192,7 @@ private:
*/
GrTextContext* getTextContext();
- typedef SkDevice INHERITED;
+ typedef SkBitmapDevice INHERITED;
};
#endif
@@ -22,10 +22,10 @@ struct GrSkDrawProcs;
class GrTextContext;
/**
- * Subclass of SkDevice, which directs all drawing to the GrGpu owned by the
+ * Subclass of SkBitmapDevice, which directs all drawing to the GrGpu owned by the
* canvas.
*/
@@ -62,7 +62,7 @@ public:
virtual GrRenderTarget* accessRenderTarget() SK_OVERRIDE;
- // overrides from SkDevice
+ // overrides from SkBaseDevice
virtual void clear(SkColor color) SK_OVERRIDE;
virtual void writePixels(const SkBitmap& bitmap, int x, int y,
@@ -123,7 +123,7 @@ public:
class SkAutoCachedTexture; // used internally
protected:
- // overrides from SkDevice
+ // overrides from SkBaseDevice
virtual bool onReadPixels(const SkBitmap& bitmap,
int x, int y,